# Cloud Spanner Executor test API


Stop. This folder is likely not what you are looking for.

This folder contains protocol buffer definitions for test-only API for
Cloud Spanner clients. Unless told otherwise by a Google Cloud representative,
do not use any of the contents of this folder. If you would like to use Cloud
Spanner, please consult our
[official documentation](https://cloud.google.com/spanner/docs/apis) for details
on our APIs, or else consider one of our
[client libraries](https://cloud.google.com/spanner/docs/reference/libraries).

This API defined in this folder is unreleased and may shut off, break, or fail
at any time for any users who are not registered as a part of a private preview
program.
